# Google Workspace Automation Toolbox

## Installation

1. Install from pypi

   ```bash
   pip install -U googau
   ```

1. Install for development

   ```bash
   virtualenv -p python3 venv
   source venv/bin/activate
   pip install poetry
   poetry install
   ```

### References and links

Google API documentation - [https://developers.google.com/](https://developers.google.com/)
